Changelog
=========


Version 0.2.0
-------------

Released on Feb 8th 2016

- Added example documentation.
- Added Exceptions.
- Added logger (`logging.getLogger('avenue')`).
- Added more code coverage.
- Added solve `Skip` option.
- Updated code to match Flake8 requirements.
- Updated requirements.
- Updated to have no more strict Sphinx builds.
- Updated tox checks.
- Fixed bug in sorting `Match`.
- After extended use of `0.1.5` I deemed this project ready for it's `0.2` phase.

Version 0.1.5
-------------

Released on Feb 8th 2016

- Added documation coverage.
- Added missing route option.
- Added more code coverage.
- Updated requirements.

Version 0.1.4
-------------

Released on Jan 28th 2016

- Fixed source URI.

Version 0.1.3
-------------

Released on Jan 28th 2016

- Added `Assemble` to build package.

Version 0.1.2
-------------

Released on Jan 27th 2016

- Added more tests.
- Added `Assemble` to build package.
- Added a simple example.

Version 0.1.0
-------------

Released on Jan 26st 2016

- Initial release
